==> qstardict-debug-3.0.0-1-x86_64.pkg.tar.zst: usr/src/debug/qstardict/qstardict-3.0.0/plugins/swac/qrc_pixmaps.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // sound.png
  0x0,0x0,0x3,0x2f,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0x0,0x0,0x0,0x0,0x0,0xf9,0x43,
  0xbb,0x7f,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x2,0xa1,0x49,0x44,0x41,0x54,0x38,
  0xcb,0x8d,0x93,0x5f,0x48,0x95,0x77,0x18,0xc7,0x3f,0xcf,0xef,0xf5,0x84,0x88,0x94,
  0x69,0xb9,0x69,0x56,0xda,0x74,0xd3,0x2e,0x16,0xec,0xf,0x2c,0x5a,0x61,0x54,0x6,
  0x6d,0x5,0x13,0xaf,0x8b,0x50,0xba,0x98,0x17,0x5,0x5d,0x6c,0x17,0x6d,0xac,0xd1,
  0x60,0xab,0xed,0x6a,0x83,0x11,0x6b,0xd0,0x3f,0xba,0x88,0x5,0xad,0x40,0xa2,0x22,
  0x5a,0x8e,0x82,0xda,0x4a,0x2f,0xb2,0xb4,0xf0,0x84,0x53,0xb0,0x93,0xd8,0x39,0x79,
  0x3c,0xe7,0x7d,0xdf,0xf3,0x9e,0xf7,0xbb,0xb,0x93,0x88,0xd8,0xf0,0xb,0xf,0x3c,
  0xf0,0xfc,0xe1,0xfb,0xf0,0x7c,0xbf,0xc6,0x1c,0xd0,0xb2,0xb1,0x13,0xc,0x64,0x20,
  0x67,0x10,0x8b,0xc1,0x8b,0xbf,0x2,0xe0,0xe6,0xb2,0x0,0x83,0xc8,0x19,0xc8,0x9a,
  0x2c,0xe6,0x3d,0x64,0x25,0xcd,0x9b,0xba,0x66,0x4b,0x2f,0xe3,0xdb,0xc3,0xa7,0x9,
  0x2,0xbf,0x6a,0x59,0xed,0xeb,0xeb,0x7,0x93,0xa3,0x17,0x32,0x53,0xd3,0xd9,0x2b,
  0x37,0xfa,0x67,0x9b,0xe7,0x63,0xec,0x13,0x9a,0x46,0x1c,0x4,0xf2,0x2f,0x31,0xd8,
  0xff,0xe3,0x29,0x86,0x86,0x47,0x2a,0x36,0xaf,0x7d,0xff,0xbb,0xd6,0xf,0xde,0xfe,
  0xa9,0xa6,0xba,0xb2,0xa1,0x7b,0xfb,0x36,0xcc,0x48,0x98,0x69,0x3d,0xc6,0x22,0xe0,
  0x30,0xb2,0x76,0x8c,0x5d,0x66,0xf6,0xe2,0x84,0xcf,0xbf,0x3f,0xca,0xd0,0xf0,0x48,
  0x45,0xc7,0x96,0xd6,0x43,0x4d,0xd,0x75,0x3b,0xcb,0xcb,0x4a,0xe7,0x39,0xb3,0xc4,
  0xd6,0xae,0x2f,0xde,0x41,0x6a,0x11,0x4c,0x0,0x5f,0xb,0x1c,0x46,0x8f,0xc1,0xa7,
  0x82,0x46,0x7,0x20,0x89,0x7b,0x43,0xc3,0xb,0xb7,0x6c,0x58,0x73,0xa8,0x7e,0x69,
  0xed,0x4e,0xcc,0xb9,0xcc,0x54,0xae,0xfc,0xf2,0xf5,0x3b,0x1d,0xc5,0xa2,0x32,0x32,
  0xdb,0x83,0xcc,0x21,0xc6,0xd,0x76,0x19,0xfc,0x29,0xac,0x16,0xd8,0xe0,0xae,0xf6,
  0x25,0xd9,0x7b,0xf0,0x58,0xc7,0x47,0x6d,0xad,0x67,0x97,0xd4,0x54,0xef,0x10,0x78,
  0x7e,0x50,0x20,0xe7,0x87,0x89,0xc9,0xf4,0xd4,0xee,0x44,0x89,0xd7,0x68,0x30,0xa,
  0x7c,0x82,0x71,0x5b,0xb0,0x46,0xe2,0x99,0x89,0xc0,0xe0,0x5d,0xb7,0x62,0xf9,0x52,
  0x2a,0x2b,0x16,0xac,0xaa,0xaa,0x5c,0xb8,0x2e,0x16,0x89,0x7c,0x50,0xc0,0xf,0xb,
  0x4,0x85,0x88,0x38,0x56,0x99,0x73,0xd6,0x24,0x31,0x8e,0x69,0xb9,0xa4,0x34,0x68,
  0xfe,0xf3,0xef,0xf9,0x82,0x45,0x2e,0x9d,0xcd,0xe1,0x87,0x5,0x72,0x7e,0x88,0x1f,
  0x44,0xf8,0xe1,0x4c,0x4,0x61,0x84,0x90,0x4,0x59,0xa0,0xcc,0xb0,0x14,0xe0,0xc,
  0x2,0x43,0xd1,0xf3,0x3c,0xe7,0x6e,0xf5,0xdd,0x65,0x6c,0x3c,0x75,0x29,0x39,0x32,
  0x76,0x24,0x3d,0x95,0x9d,0xe,0xc2,0x8,0x3f,0x98,0x61,0xe0,0x39,0x6f,0x20,0x2e,
  0xc6,0x7d,0x98,0xea,0x84,0xce,0x1b,0x56,0xf,0x36,0x88,0x21,0x50,0xa9,0xd0,0x80,
  0xeb,0xdc,0xba,0x9a,0xc7,0xa9,0x27,0xd7,0x4e,0xfc,0x76,0xbe,0xfb,0x61,0xf2,0x9f,
  0x6f,0x9e,0x3e,0xcb,0xe6,0xfc,0xb0,0x80,0x99,0xcb,0x36,0x35,0x2c,0xf9,0xac,0x18,
  0xc7,0x19,0xb0,0x33,0x88,0x7e,0x99,0x56,0x9,0x1d,0x93,0x6c,0x5,0x58,0xde,0xc4,
  0x15,0x7,0xd0,0xf3,0xcb,0x7e,0xde,0x7a,0xa3,0x3e,0x3c,0x79,0xa6,0xe7,0x87,0x7,
  0xc3,0x23,0x7,0x26,0x33,0xd9,0x7c,0x31,0x56,0x54,0x57,0x53,0x3d,0xf6,0xe8,0x8f,
  0xe3,0x49,0x93,0x7a,0xcd,0xac,0x11,0xd9,0x59,0xe0,0x1a,0xa6,0x8f,0x5,0xe7,0x84,
  0xfd,0xe5,0xcd,0xea,0x60,0xe8,0xef,0xab,0x7c,0xb8,0xb9,0xbd,0x78,0xb9,0xf7,0xe6,
  0xcd,0x86,0x65,0xb5,0x91,0x99,0xbd,0x39,0x3a,0x9e,0x3a,0x71,0xa1,0xf7,0xf6,0xc4,
  0x83,0x47,0xa3,0x0,0x93,0x91,0xe3,0xbe,0x7,0x6d,0x86,0xad,0x4,0xbe,0x2,0xd2,
  0xaf,0x48,0xb9,0xbd,0xfb,0x0,0x25,0x9e,0x57,0xfa,0xda,0xe2,0xaa,0x96,0x89,0xa7,
  0xe9,0x81,0x5c,0xde,0xf,0x7e,0xff,0xf9,0x4b,0x9a,0xdb,0x3a,0x1,0xca,0x11,0xab,
  0xc1,0xfa,0x85,0x52,0x1e,0x25,0xaf,0x7a,0xe1,0xbf,0xd0,0xbc,0xa9,0xb,0x4c,0x33,
  0x8e,0x10,0xdc,0xbf,0x74,0x64,0xae,0xa3,0xff,0x8f,0x7f,0x1,0xf3,0x5,0x38,0xe8,
  0x27,0xb3,0xcf,0x94,0x0,0x0,0x0,0x22,0x7a,0x54,0x58,0x74,0x53,0x6f,0x66,0x74,
  0x77,0x61,0x72,0x65,0x0,0x0,0x78,0xda,0x2b,0x2f,0x2f,0xd7,0xcb,0xcc,0xcb,0x2e,
  0x4e,0x4e,0x2c,0x48,0xd5,0xcb,0x2f,0x4a,0x7,0x0,0x36,0xd8,0x6,0x58,0x10,0x53,
  0xca,0x5c,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // sound.png
  0x0,0x9,
  0xc,0x47,0xa3,0x87,
  0x0,0x73,
  0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x94,0x2,0x54,0xc3,0x28,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x94,0x2,0x54,0xc3,0x28,
  // :/icons/sound.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x94,0x2,0x54,0xc3,0x28,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_pixmaps)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_pixmaps)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_pixmaps)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_pixmaps)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_pixmaps)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_pixmaps)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> qstardict-debug-3.0.0-1.1-x86_64.pkg.tar.zst: usr/src/debug/qstardict/qstardict-3.0.0/plugins/swac/qrc_pixmaps.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.8.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // sound.png
  0x0,0x0,0x3,0x2f,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0x0,0x0,0x0,0x0,0x0,0xf9,0x43,
  0xbb,0x7f,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x2,0xa1,0x49,0x44,0x41,0x54,0x38,
  0xcb,0x8d,0x93,0x5f,0x48,0x95,0x77,0x18,0xc7,0x3f,0xcf,0xef,0xf5,0x84,0x88,0x94,
  0x69,0xb9,0x69,0x56,0xda,0x74,0xd3,0x2e,0x16,0xec,0xf,0x2c,0x5a,0x61,0x54,0x6,
  0x6d,0x5,0x13,0xaf,0x8b,0x50,0xba,0x98,0x17,0x5,0x5d,0x6c,0x17,0x6d,0xac,0xd1,
  0x60,0xab,0xed,0x6a,0x83,0x11,0x6b,0xd0,0x3f,0xba,0x88,0x5,0xad,0x40,0xa2,0x22,
  0x5a,0x8e,0x82,0xda,0x4a,0x2f,0xb2,0xb4,0xf0,0x84,0x53,0xb0,0x93,0xd8,0x39,0x79,
  0x3c,0xe7,0x7d,0xdf,0xf3,0x9e,0xf7,0xbb,0xb,0x93,0x88,0xd8,0xf0,0xb,0xf,0x3c,
  0xf0,0xfc,0xe1,0xfb,0xf0,0x7c,0xbf,0xc6,0x1c,0xd0,0xb2,0xb1,0x13,0xc,0x64,0x20,
  0x67,0x10,0x8b,0xc1,0x8b,0xbf,0x2,0xe0,0xe6,0xb2,0x0,0x83,0xc8,0x19,0xc8,0x9a,
  0x2c,0xe6,0x3d,0x64,0x25,0xcd,0x9b,0xba,0x66,0x4b,0x2f,0xe3,0xdb,0xc3,0xa7,0x9,
  0x2,0xbf,0x6a,0x59,0xed,0xeb,0xeb,0x7,0x93,0xa3,0x17,0x32,0x53,0xd3,0xd9,0x2b,
  0x37,0xfa,0x67,0x9b,0xe7,0x63,0xec,0x13,0x9a,0x46,0x1c,0x4,0xf2,0x2f,0x31,0xd8,
  0xff,0xe3,0x29,0x86,0x86,0x47,0x2a,0x36,0xaf,0x7d,0xff,0xbb,0xd6,0xf,0xde,0xfe,
  0xa9,0xa6,0xba,0xb2,0xa1,0x7b,0xfb,0x36,0xcc,0x48,0x98,0x69,0x3d,0xc6,0x22,0xe0,
  0x30,0xb2,0x76,0x8c,0x5d,0x66,0xf6,0xe2,0x84,0xcf,0xbf,0x3f,0xca,0xd0,0xf0,0x48,
  0x45,0xc7,0x96,0xd6,0x43,0x4d,0xd,0x75,0x3b,0xcb,0xcb,0x4a,0xe7,0x39,0xb3,0xc4,
  0xd6,0xae,0x2f,0xde,0x41,0x6a,0x11,0x4c,0x0,0x5f,0xb,0x1c,0x46,0x8f,0xc1,0xa7,
  0x82,0x46,0x7,0x20,0x89,0x7b,0x43,0xc3,0xb,0xb7,0x6c,0x58,0x73,0xa8,0x7e,0x69,
  0xed,0x4e,0xcc,0xb9,0xcc,0x54,0xae,0xfc,0xf2,0xf5,0x3b,0x1d,0xc5,0xa2,0x32,0x32,
  0xdb,0x83,0xcc,0x21,0xc6,0xd,0x76,0x19,0xfc,0x29,0xac,0x16,0xd8,0xe0,0xae,0xf6,
  0x25,0xd9,0x7b,0xf0,0x58,0xc7,0x47,0x6d,0xad,0x67,0x97,0xd4,0x54,0xef,0x10,0x78,
  0x7e,0x50,0x20,0xe7,0x87,0x89,0xc9,0xf4,0xd4,0xee,0x44,0x89,0xd7,0x68,0x30,0xa,
  0x7c,0x82,0x71,0x5b,0xb0,0x46,0xe2,0x99,0x89,0xc0,0xe0,0x5d,0xb7,0x62,0xf9,0x52,
  0x2a,0x2b,0x16,0xac,0xaa,0xaa,0x5c,0xb8,0x2e,0x16,0x89,0x7c,0x50,0xc0,0xf,0xb,
  0x4,0x85,0x88,0x38,0x56,0x99,0x73,0xd6,0x24,0x31,0x8e,0x69,0xb9,0xa4,0x34,0x68,
  0xfe,0xf3,0xef,0xf9,0x82,0x45,0x2e,0x9d,0xcd,0xe1,0x87,0x5,0x72,0x7e,0x88,0x1f,
  0x44,0xf8,0xe1,0x4c,0x4,0x61,0x84,0x90,0x4,0x59,0xa0,0xcc,0xb0,0x14,0xe0,0xc,
  0x2,0x43,0xd1,0xf3,0x3c,0xe7,0x6e,0xf5,0xdd,0x65,0x6c,0x3c,0x75,0x29,0x39,0x32,
  0x76,0x24,0x3d,0x95,0x9d,0xe,0xc2,0x8,0x3f,0x98,0x61,0xe0,0x39,0x6f,0x20,0x2e,
  0xc6,0x7d,0x98,0xea,0x84,0xce,0x1b,0x56,0xf,0x36,0x88,0x21,0x50,0xa9,0xd0,0x80,
  0xeb,0xdc,0xba,0x9a,0xc7,0xa9,0x27,0xd7,0x4e,0xfc,0x76,0xbe,0xfb,0x61,0xf2,0x9f,
  0x6f,0x9e,0x3e,0xcb,0xe6,0xfc,0xb0,0x80,0x99,0xcb,0x36,0x35,0x2c,0xf9,0xac,0x18,
  0xc7,0x19,0xb0,0x33,0x88,0x7e,0x99,0x56,0x9,0x1d,0x93,0x6c,0x5,0x58,0xde,0xc4,
  0x15,0x7,0xd0,0xf3,0xcb,0x7e,0xde,0x7a,0xa3,0x3e,0x3c,0x79,0xa6,0xe7,0x87,0x7,
  0xc3,0x23,0x7,0x26,0x33,0xd9,0x7c,0x31,0x56,0x54,0x57,0x53,0x3d,0xf6,0xe8,0x8f,
  0xe3,0x49,0x93,0x7a,0xcd,0xac,0x11,0xd9,0x59,0xe0,0x1a,0xa6,0x8f,0x5,0xe7,0x84,
  0xfd,0xe5,0xcd,0xea,0x60,0xe8,0xef,0xab,0x7c,0xb8,0xb9,0xbd,0x78,0xb9,0xf7,0xe6,
  0xcd,0x86,0x65,0xb5,0x91,0x99,0xbd,0x39,0x3a,0x9e,0x3a,0x71,0xa1,0xf7,0xf6,0xc4,
  0x83,0x47,0xa3,0x0,0x93,0x91,0xe3,0xbe,0x7,0x6d,0x86,0xad,0x4,0xbe,0x2,0xd2,
  0xaf,0x48,0xb9,0xbd,0xfb,0x0,0x25,0x9e,0x57,0xfa,0xda,0xe2,0xaa,0x96,0x89,0xa7,
  0xe9,0x81,0x5c,0xde,0xf,0x7e,0xff,0xf9,0x4b,0x9a,0xdb,0x3a,0x1,0xca,0x11,0xab,
  0xc1,0xfa,0x85,0x52,0x1e,0x25,0xaf,0x7a,0xe1,0xbf,0xd0,0xbc,0xa9,0xb,0x4c,0x33,
  0x8e,0x10,0xdc,0xbf,0x74,0x64,0xae,0xa3,0xff,0x8f,0x7f,0x1,0xf3,0x5,0x38,0xe8,
  0x27,0xb3,0xcf,0x94,0x0,0x0,0x0,0x22,0x7a,0x54,0x58,0x74,0x53,0x6f,0x66,0x74,
  0x77,0x61,0x72,0x65,0x0,0x0,0x78,0xda,0x2b,0x2f,0x2f,0xd7,0xcb,0xcc,0xcb,0x2e,
  0x4e,0x4e,0x2c,0x48,0xd5,0xcb,0x2f,0x4a,0x7,0x0,0x36,0xd8,0x6,0x58,0x10,0x53,
  0xca,0x5c,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // sound.png
  0x0,0x9,
  0xc,0x47,0xa3,0x87,
  0x0,0x73,
  0x0,0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x94,0x2,0x5d,0x5a,0x60,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x94,0x2,0x5d,0x5a,0x60,
  // :/icons/sound.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x94,0x2,0x5d,0x5a,0x60,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_pixmaps)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_pixmaps)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_pixmaps)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_pixmaps)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_pixmaps)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_pixmaps)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
